import i18n from '@/i18n';

export const ModuleConfig = {
    enabled: true,
    routerPrefix: 'settings',
    loadOrder: 30,
    moduleName: 'AmazingCat_GitlabIntegration',
};

export function init(context, router) {
    const requireSection = require.context('.', true, /^(?!.*(service|module)).*\.js$/);
    const sections = requireSection
        .keys()
        .map(fn => requireSection(fn).default)
        .map(section => {
            if (typeof section === 'function') {
                return section(context, router);
            }
            return section;
        });

    sections.forEach(section => {
        if (section.hasOwnProperty('scope') && section.scope === 'company') {
            context.addCompanySection(section);
        } else {
            context.addSettingsSection(section);
        }
    });

    context.addField('company', 'general', {
        label: 'settings.gitlab.label',
        key: 'gitlab_enabled',
        group: 'integrations',
        render(h, data) {
            if (typeof data.currentValue === 'object') {
                'gitlab_enabled' in data.companyData
                    ? data.inputHandler(data.companyData.gitlab_enabled)
                    : (data.currentValue = '0');

                this.inputHandler(data.currentValue);
            }
            return h(
                'at-select',
                {
                    props: {
                        value: data.currentValue.toString(),
                    },
                    class: {
                        'with-margin': true,
                    },
                    on: {
                        'on-change': value => {
                            data.inputHandler(value);
                        },
                    },
                },
                [
                    h('at-option', {
                        props: {
                            value: '0',
                            label: i18n.t('control.disable'),
                        },
                    }),
                    h('at-option', {
                        props: {
                            value: '1',
                            label: i18n.t('control.enable'),
                        },
                    }),
                ],
            );
        },
    });

    context.addLocalizationData({
        en: require('./locales/en'),
        ru: require('./locales/ru'),
    });

    return context;
}
